@@ -1,11 +1,12 @@
+use clap::Parser;
 use nothing::Probably;
 use std::env;
 use std::path::{Path, PathBuf};
 
 /// find binary for command
 ///
-/// https://stackoverflow.com/questions/37498864/finding-executable-in-path-with-rust
-pub fn find_it<P>(exe_name: P) -> Probably<PathBuf>
+/// <https://stackoverflow.com/questions/37498864/finding-executable-in-path-with-rust>
+pub fn locate<P>(exe_name: P) -> Probably<PathBuf>
 where
     P: AsRef<Path>,
 {
@@ -24,3 +25,17 @@ where
         })
         .into()
 }
+
+/// clap::Parser struct
+#[derive(Parser)]
+pub struct Args {
+    /// command name
+    pub command: String,
+}
+
+impl Args {
+    /// find command path
+    pub fn locate(self) -> Probably<PathBuf> {
+        locate(self.command)
+    }
+}
